package com.huiju.foyo.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.foyo.common.BaseController;
import com.huiju.foyo.common.ConstantFoyo;
import com.huiju.foyo.common.ResponseBean;
import com.huiju.foyo.model.TaCase;
import com.huiju.foyo.service.ITaCaseService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDateTime;
import java.util.Arrays;
import java.util.List;

/**
 * <p>
    * 案例表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-08-21
 */
@RestController
@RequestMapping("/")
public class TaCaseController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaCaseController.class);

    @Autowired
    public ITaCaseService iTaCaseService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/case/list",method= RequestMethod.GET)
    public ResponseBean taCaseList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                   @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaCase> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaCase> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("status", ConstantFoyo.STATUS_EFFECTIVE);
            queryWrapper.orderByDesc("sort");
            queryWrapper.orderByDesc("create_time");

            IPage<TaCase> result = iTaCaseService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taCaseList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taCase 实体对象
     * @return
     */
    @RequestMapping(value="/admin/case/add",method= RequestMethod.POST)
    public ResponseBean taCaseAdd(@RequestBody TaCase taCase){
        ResponseBean responseBean = new ResponseBean();
        try {
            taCase.setStatus(ConstantFoyo.STATUS_EFFECTIVE);
            taCase.setCreateBy(ConstantFoyo.USER_ADMIN);
            taCase.setCreateTime(LocalDateTime.now());
            if (iTaCaseService.save(taCase)){
                responseBean.addSuccess(taCase);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taCaseAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     */
    @ResponseBody
    @RequestMapping(value="/admin/case/delete", method= RequestMethod.DELETE)
    public ResponseBean taCaseDelete(@RequestBody String[] ids){
        ResponseBean responseBean = new ResponseBean();
        try {
            List<String> idList = Arrays.asList(ids);
            if(iTaCaseService.removeByIds(idList)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taCaseDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taCase 实体对象
     * @return
     */
    @RequestMapping(value="/taCase/{id}",method= RequestMethod.PUT)
    public ResponseBean taCaseUpdate(@PathVariable Integer id,
                                        @RequestBody TaCase taCase){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaCaseService.updateById(taCase)){
                responseBean.addSuccess(taCase);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taCaseUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/case/{id}",method= RequestMethod.GET)
    public ResponseBean taCaseGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaCaseService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taCaseDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
    
    /**
     * 分页查询列表
     * @return
     */
    @RequestMapping(value="/pc/case/list",method= RequestMethod.GET)
    public ResponseBean pcCaseList(){
        ResponseBean responseBean = new ResponseBean();
        try {
            QueryWrapper<TaCase> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("status", ConstantFoyo.STATUS_EFFECTIVE);
            queryWrapper.orderByDesc("sort");
            queryWrapper.orderByDesc("create_time");
            queryWrapper.last("limit 3");
            responseBean.addSuccess(iTaCaseService.list(queryWrapper));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taCaseList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
