import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/views/layout/Layout'

/** note: Submenu only appear when children.length>=1
 *  detail see  https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 **/

/**
* hidden: true                   if `hidden:true` will not show in the sidebar(default is false)
* alwaysShow: true               if set true, will always show the root menu, whatever its child routes length
*                                if not set alwaysShow, only more than one route under the children
*                                it will becomes nested mode, otherwise not show the root menu
* redirect: noredirect           if `redirect:noredirect` will no redirect in the breadcrumb
* name:'router-name'             the name is used by <keep-alive> (must set!!!)
* meta : {
    roles: ['admin','editor']     will control the page roles (you can set multiple roles)
    title: 'title'               the name show in submenu and breadcrumb (recommend set)
    icon: 'svg-name'             the icon show in the sidebar,
    noCache: true                if true ,the page will no be cached(default is false)
  }
**/
export const constantRouterMap = [
  {
    path: '/redirect',
    component: Layout,
    hidden: true,
    children: [
      {
        path: '/redirect/:path*',
        component: () => import('@/views/redirect/index')
      }
    ]
  },
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },
  {
    path: '/auth-redirect',
    component: () => import('@/views/login/authredirect'),
    hidden: true
  },
  {
    path: '/404',
    component: () => import('@/views/errorPage/404'),
    hidden: true
  },
  {
    path: '/401',
    component: () => import('@/views/errorPage/401'),
    hidden: true
  },
  {
    path: '',
    component: Layout,
    redirect: 'dashboard',
    children: [
      {
        path: 'dashboard',
        component: () => import('@/views/dashboard/index'),
        name: 'Dashboard',
        meta: { title: 'dashboard', icon: 'dashboard', noCache: true }
      }
    ]
  },
  {
    path: '/service',
    component: Layout,
    redirect: '/conmmunity/download',
    name: 'service',
    alwaysShow: true,
    meta: { title: '服务管理', icon: 'zip' },
    children: [
      {
        path: 'service',
        component: () => import('@/views/service/index'),
        name: 'service-index',
        meta: { title: '服务列表', icon: 'table' }
      },
      {
        path: '/service/edit',
        component: () => import('@/views/service/edit'),
        name: 'service-edit',
        hidden: true,
        meta: { title: '添加业务信息', icon: 'table' }
      }
    ]
  },
  {
    path: '/carousel',
    component: Layout,
    redirect: '/conmmunity/download',
    name: 'carousel',
    alwaysShow: true,
    meta: { title: '轮播图管理', icon: 'zip' },
    children: [
      {
        path: 'carousel',
        component: () => import('@/views/carousel/index'),
        name: 'carousel-index',
        meta: { title: '轮播图列表', icon: 'carousel' }
      },
      {
        path: '/carousel/edit',
        component: () => import('@/views/carousel/edit'),
        name: 'carousel-edit',
        hidden: true,
        meta: { title: '新增轮播图', icon: 'table' }
      }
    ]
  },
  {
    path: '/case',
    component: Layout,
    redirect: '/conmmunity/download',
    name: 'case',
    alwaysShow: true,
    meta: { title: '案例管理', icon: 'zip' },
    children: [
      {
        path: 'case',
        component: () => import('@/views/case/index'),
        name: 'case-index',
        meta: { title: '案例列表', icon: 'table' }
      },
      {
        path: '/case/add',
        component: () => import('@/views/case/add'),
        name: 'case-add',
        hidden: true,
        meta: { title: '添加案例信息', icon: 'table' }
      },
      {
        path: '/case/edit',
        component: () => import('@/views/case/edit'),
        name: 'case-edit',
        hidden: true,
        meta: { title: '编辑案例信息', icon: 'table' }
      },
      {
        path: '/case/cover',
        component: () => import('@/views/case/cover'),
        name: 'case-cover',
        meta: { title: '编辑封面图', icon: 'table' }
      },
      {
        path: '/servicecase',
        component: () => import('@/views/case/servicecase/index'),
        name: 'servicecase-index',
        meta: { title: '案例类型列表', icon: 'table' }
      },
      {
        path: '/servicecase/add',
        component: () => import('@/views/case/servicecase/add'),
        name: 'servicecase-add',
        hidden: true,
        meta: { title: '新增案例类型', icon: 'table' }
      },
      {
        path: '/company/index',
        component: () => import('@/views/company/edit'),
        name: 'company-index',
        meta: { title: '编辑公司信息', icon: 'table' }
      }
    ]
  },
  {
    path: '/partner',
    component: Layout,
    redirect: '/conmmunity/download',
    name: 'partner',
    alwaysShow: true,
    meta: { title: '合作伙伴管理', icon: 'zip' },
    children: [
      {
        path: 'carousel',
        component: () => import('@/views/partner/index'),
        name: 'partner-index',
        meta: { title: '合作伙伴列表', icon: 'table' }
      },
      {
        path: '/partner/edit',
        component: () => import('@/views/partner/add'),
        name: 'partner-edit',
        hidden: true,
        meta: { title: '新增合作伙伴', icon: 'table' }
      }
    ]
  }
]

export default new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRouterMap
})
